==> ocp-common-5.0.0-20210622.032615-46-sources.jar: com/efuture/ocp/common/rest/taobao/TaobaoSession.java <==
package com.efuture.ocp.common.rest.taobao;

/**
 * 奇门session
 */
public class TaobaoSession {

    private long ent_id;
    private String app_key;
    private String target_app_key;
    private String source_appkey;
    private String request_id;
    private String cmd;
    private String method;
    private String v;
    private String sign;
    private String timestamp;
    private String partner_id;
    private String format;
    private String sign_method;

    public long getEnt_id() {
        return ent_id;
    }

    public void setEnt_id(long ent_id) {
        this.ent_id = ent_id;
    }

    public String getApp_key() {
        return app_key;
    }

    public void setApp_key(String app_key) {
        this.app_key = app_key;
    }

    public String getMethod() {
        return method;
    }

    public void setMethod(String method) {
        this.method = method;
    }

    public String getV() {
        return v;
    }

    public void setV(String v) {
        this.v = v;
    }

    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }

    public String getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(String timestamp) {
        this.timestamp = timestamp;
    }

    public String getTarget_app_key() {
        return target_app_key;
    }

    public void setTarget_app_key(String target_app_key) {
        this.target_app_key = target_app_key;
    }

    public String getPartner_id() {
        return partner_id;
    }

    public void setPartner_id(String partner_id) {
        this.partner_id = partner_id;
    }

    public String getFormat() {
        return format;
    }

    public void setFormat(String format) {
        this.format = format;
    }

    public String getSign_method() {
        return sign_method;
    }

    public void setSign_method(String sign_method) {
        this.sign_method = sign_method;
    }

    public String getRequest_id() {
        return request_id;
    }

    public void setRequest_id(String request_id) {
        this.request_id = request_id;
    }

    public String getSource_appkey() {
        return source_appkey;
    }

    public void setSource_appkey(String source_appkey) {
        this.source_appkey = source_appkey;
    }

    public String getCmd() {
        return cmd;
    }

    public void setCmd(String cmd) {
        this.cmd = cmd;
    }
}

==> ocp-common-5.0.0-20230803.083541-98-sources.jar: com/efuture/ocp/common/rest/taobao/TaobaoSession.java <==
package com.efuture.ocp.common.rest.taobao;

/**
 * 奇门session
 */
public class TaobaoSession {

    private long ent_id;
    private String app_key;
    private String target_appkey;
    private String source_appkey;
    private String request_id;
    private String cmd;
    private String method;
    private String sign;
    private String timestamp;
    private String format;
    private String sign_method;

    public long getEnt_id() {
        return ent_id;
    }

    public void setEnt_id(long ent_id) {
        this.ent_id = ent_id;
    }

    public String getApp_key() {
        return app_key;
    }

    public void setApp_key(String app_key) {
        this.app_key = app_key;
    }

    public String getMethod() {
        return method;
    }

    public void setMethod(String method) {
        this.method = method;
    }

    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }

    public String getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(String timestamp) {
        this.timestamp = timestamp;
    }

    public String getTarget_appkey() {
        return target_appkey;
    }

    public void setTarget_appkey(String target_appkey) {
        this.target_appkey = target_appkey;
    }

    public String getFormat() {
        return format;
    }

    public void setFormat(String format) {
        this.format = format;
    }

    public String getSign_method() {
        return sign_method;
    }

    public void setSign_method(String sign_method) {
        this.sign_method = sign_method;
    }

    public String getRequest_id() {
        return request_id;
    }

    public void setRequest_id(String request_id) {
        this.request_id = request_id;
    }

    public String getSource_appkey() {
        return source_appkey;
    }

    public void setSource_appkey(String source_appkey) {
        this.source_appkey = source_appkey;
    }

    public String getCmd() {
        return cmd;
    }

    public void setCmd(String cmd) {
        this.cmd = cmd;
    }
}
